@@ -13,5 +13,5 @@ count_logical <- function(x, nThread = getOption("hutilscpp.nThread", 1L)) {
     stop(g("`x` was type {typeof(x)}, but must be type logical."))
   }
   nThread <- check_omp(nThread)
-  .Call("Ccount_logical", x, nThread, PACKAGE = packageName)
+  as_integer_if_safe(.Call("Ccount_logical", x, nThread, PACKAGE = packageName))
 }
