@@ -102,10 +102,14 @@ is_constant <- function(x, nThread = getOption("hutilscpp.nThread", 1L)) {
     stop("`x` was not atomic. ",
          "Such objects are not supported.")
   }
-  if (is.double(x) && is.na(x[1])) {
-    return(all_na_real(x, nThread = nThread))
+  nThread <- check_omp(nThread)
+  ans <- .Call("Cis_constant", x, nThread, PACKAGE = packageName)
+  # nocov start
+  if (is.null(ans)) {
+    return(identical(rep_len(x[1], length(x)), x))
   }
-  do_is_constant(x, nThread = nThread)
+  # nocov end
+  ans
 }
 
 #' @rdname is_constant
@@ -143,5 +147,17 @@ isntConstant <- function(x) {
     }
   }
 
-  do_isntConstant(x)
+  ans <- .Call("Cisnt_constant", x, PACKAGE = packageName)
+  # nocov start
+  if (is.null(ans)) {
+    x1 <- x[1L]
+    for (i in seq_along(ans)) {
+      if (x[i] != x1) {
+        return(i)
+      }
+    }
+    return(0L)
+  }
+  # nocov end
+  ans
 }
